from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="dtbag",
    version="3.0.3",
    author="Abderrahmane Sakhi",
    author_email="Abderrahmane.Sakhi@gmail.com",
    description="Data Tool Bag (dtbag) - A Python library for text processing, data cleaning, and similarity-based clustering of textual data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/abderrahmane-sakhi/dtbag",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Financial and Insurance Industry",
        "Intended Audience :: Healthcare Industry",
        "Intended Audience :: Manufacturing",
	"Intended Audience :: Developers",
        "Intended Audience :: Other Audience",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Topic :: Office/Business",
        "Topic :: Text Processing",
	],
    python_requires=">=3.6",

    keywords=[
    "categorical data unification",
    "text processing",
    "data cleaning",
    "text normalization",
    "string matching",
    "similarity detection",
    "data preprocessing",
    "text cleaning",
    "text unification",
    "duplicate detection",
    "data deduplication",
    "text clustering",
    "levenshtein distance",
    "fuzzy matching",
    "clustering algorithms",
    "pattern recognition",
    "natural language processing",
    "text mining",
    "similarity metrics",
    "edit distance",
    "string similarity",
    "data science",
    "machine learning",
    "data analysis",
    "ETL tools",
    "data wrangling",
    "information retrieval",
    "python-library",
    "open-source",
    "text-utilities",
    "data-tools"
],
    project_urls={
        "Bug Reports": "https://github.com/abderrahmane-sakhi/dtbag/issues",
        "Source": "https://github.com/abderrahmane-sakhi/dtbag",
    },
)